#undef ENABLE_NLS
#undef HAVE_CATGETS
#undef HAVE_GETTEXT
#undef HAVE_LC_MESSAGES
#undef HAVE_STPCPY
#undef HAVE_STRUCT_OSOCKADDR
#undef HAVE_LIBSM
#undef HAVE_LIBINTL_H
#undef HAVE_GTK_SIGNAL_HANDLER_PENDING
#undef HAVE_PROGRAM_INVOCATION_SHORT_NAME
#undef HAVE_PROGRAM_INVOCATION_NAME
#undef HAVE_SYS_ERRLIST
#undef HAVE_LIBJPEG
#undef HAVE_LIBGIF
#undef HAVE_LIBTIFF
#undef HAVE_LIBZ
#undef HAVE_LIBPNG
#undef GNOME_ENABLE_DEBUG
#undef NEED_DECLARATION_GETHOSTNAME
#undef HAVE_SOCKET
#undef HAVE_STRUCT_LINGER
#undef USE_EXT2FSLIB
#undef USE_NETCODE
#undef USE_TERMNET
#undef USE_VFS
#undef HAVE_ESD
#undef PACKAGE
#undef VERSION
#undef USE_POPT
#undef HAVE_LIBAUDIOFILE
#undef umode_t
#undef HAVE_OPENPTY
#undef HAVE_PTY_H
#undef HAVE_UTIL_H
#undef HAVE_SENDMSG
#undef NEED_DECLARATION_SCANDIR
#undef HAVE_IMLIB_1_9

#undef WITH_SYMBOL_UNDERSCORE
